<?php

namespace Drupal\eca_content\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;

/**
 * Set the value of a referenced entity's field.
 *
 * @Action(
 *   id = "eca_set_field_value_entity_ref",
 *   label = @Translation("Entity: set field value of reference"),
 *   type = "entity"
 * )
 */
class SetFieldValueEntityRef extends SetFieldValue {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL): void {
    if ($entity === NULL) {
      return;
    }
    $field_name = $this->tokenServices->replaceClear($this->configuration['field_name_entity_ref']);
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    if (!$entity->hasField($field_name)) {
      // @todo: Log this error.
      return;
    }
    /** @var \Drupal\Core\Entity\ContentEntityInterface $referencedEntity */
    if ($referencedEntity = $entity->get($field_name)->first()->get('entity')->getTarget()->getValue()) {
      parent::execute($referencedEntity);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'field_name_entity_ref' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['field_name_entity_ref'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field name for entity reference'),
      '#default_value' => $this->configuration['field_name_entity_ref'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['field_name_entity_ref'] = $form_state->getValue('field_name_entity_ref');
  }

}
