<?php

namespace Drupal\Tests\eca\Unit\Service;

use Drupal\Core\Entity\EntityType;
use Drupal\eca\Service\TokenBrowserService;
use Drupal\Tests\UnitTestCase;

/**
 * Tests to token browser service.
 *
 * @group eca
 */
class TokenBrowserServiceTest extends UnitTestCase {

  public function testTokenModuleNotInstalled(): void {
    $moduleHandler = $this->createMock('\Drupal\Core\Extension\ModuleHandlerInterface');
    $entityTypeManager = $this->createMock('\Drupal\Core\Entity\EntityTypeManagerInterface');
    $tokenBrowserService = new TokenBrowserService($moduleHandler, $entityTypeManager);
    $this->assertEquals([], $tokenBrowserService->getTokenBrowserMarkup());
  }

  /**
   * @throws \Drupal\Core\Entity\Exception\EntityTypeIdLengthException
   */
  public function testGetMarkup(): void {
    $moduleHandler = $this->createMock('\Drupal\Core\Extension\ModuleHandlerInterface');
    $moduleHandler->expects($this->any())->method('moduleExists')
      ->with('token')->will($this->returnValue(TRUE));

    $entityTypeManager = $this->createMock('\Drupal\Core\Entity\EntityTypeManagerInterface');

    $entityTypes[] = new EntityType(['id' => 'node',]);
    $entityTypes[] = new EntityType(['id' => 'comment',]);
    $entityTypes[] = new EntityType(['id' => 'file',]);

    $entityTypeManager->expects($this->any())->method('getDefinitions')
      ->will($this->returnValue($entityTypes));
    $tokenBrowserService = new TokenBrowserService($moduleHandler, $entityTypeManager);

    $markup = [
      'tb' => [
        '#type' => 'container',
        '#theme' => 'token_tree_link',
        '#token_types' => ['node', 'comment', 'file'],
      ],
    ];
    $this->assertEquals($markup, $tokenBrowserService->getTokenBrowserMarkup());
  }

}